#!/usr/bin/perl
# Show a table of simple actions

require './filter-lib.pl';
&ui_print_header(undef, $text{'index_title'}, "", undef, 0, 1);

# Warn if procmail is not installed
if ($config{'warn_procmail'} && !&has_command("procmail")) {
	print "$text{'index_warn'}<p>\n";
	}

@filters = &list_filters();
@links = ( &select_all_link("d"), &select_invert_link("d"),
	   "<a href='edit.cgi?new=1'>$text{'index_add'}</a>" );

@folders = &mailbox::list_folders();
if (@filters) {
	# Show table of filters
	print &ui_form_start("delete.cgi", "post");
	@tds = ( "width=5", "width=50%", "width=50%", "width=32" );
	print &ui_links_row(\@links);
	print &ui_columns_start([ "",
				  $text{'index_condition'},
				  $text{'index_action'},
				  @filters > 1 ? ( $text{'index_move'} ) : ( ),
				], 100, 0, \@tds);

	# Add a magic non-editable row for global spamassassin run
	if (&get_global_spamassassin()) {
		print &ui_columns_row(
			[ "", $text{'index_calways'}, $text{'index_aspam'},
			  @filters > 1 ? ( "" ) : ( ) ],
			\@tds);
		}

	# Show editable rows
	foreach $f (@filters) {
		# Work out nice condition description
		local $cond;
		$lastalways = 0;
		if ($f->{'condspam'}) {
			$cond = $text{'index_cspam'};
			}
		elsif ($f->{'condheader'}) {
			$cond = &text('index_cheader',
				"<tt>$f->{'condheader'}</tt>",
			        "<tt>$f->{'condvalue'}</tt>");
			}
		elsif ($f->{'condtype'} eq '<' || $f->{'condtype'} eq '>') {
			$cond = &text('index_csize'.$f->{'condtype'},
				      &nice_size($f->{'cond'}));
			}
		elsif ($f->{'cond'}) {
			$cond = &text($f->{'body'} ? 'index_cre2' : 'index_cre',
				       "<tt>$f->{'cond'}</tt>");
			}
		else {
			$cond = $text{'index_calways'};
			if (!$f->{'continue'} && !$f->{'actionspam'}) {
				$lastalways = 1;
				}
			}
		$cond = "<a href='edit.cgi?idx=$f->{'index'}'>$cond</a>";

		# Work out nice action description
		local $action;
		if ($f->{'actionspam'}) {
			$action = $text{'index_aspam'};
			}
		elsif ($f->{'actionthrow'}) {
			$action = $text{'index_athrow'};
			}
		elsif ($f->{'actiondefault'}) {
			$action = $text{'index_adefault'};
			}
		elsif ($f->{'actiontype'} eq '!') {
			$action = &text('index_aforward',
				"<tt>$f->{'action'}</tt>");
			}
		elsif ($f->{'actionreply'}) {
			$action = &text('index_areply',
			    "<i>".&html_escape(substr(
				$f->{'reply'}->{'autotext'}, 0, 50))."</i>");
			}
		else {
			# Work out what folder
			$folder = &file_to_folder($f->{'action'}, \@folders);
			if ($folder) {
				$id = &mailbox::folder_name($folder);
				$action = &text('index_afolder',
				   "<a href='../mailbox/index.cgi?id=$id'>".
				   "$folder->{'name'}</a>");
				}
			else {
				$action = &text('index_afile',
						"<tt>$f->{'action'}</tt>");
				}
			}
		if ($f->{'continue'}) {
			$action = &text('index_acontinue', $action);
			}

		# Create mover links
		local $mover;
		if ($f eq $filters[0]) {
			$mover .= "<img src=images/gap.gif>";
			}
		else {
			$mover .= "<a href='up.cgi?idx=$f->{'index'}'>".
			      "<img src=images/up.gif border=0></a>";
			}
		if ($f eq $filters[$#filters]) {
			$mover .= "<img src=images/gap.gif>";
			}
		else {
			$mover .= "<a href='down.cgi?idx=$f->{'index'}'>".
			      "<img src=images/down.gif border=0></a>";
			}

		# Show the row
		print &ui_checked_columns_row(
			[ $cond,
			  $action,
			  @filters > 1 ? ( $mover ) : ( ) ],
			\@tds, "d", $f->{'index'}
			);

		}

	# Add a magic non-editable row for default delivery
	if (!$lastalways) {
		print &ui_columns_row(
			[ "", $text{'index_calways'}, $text{'index_adefault'},
			  @filters > 1 ? ( "" ) : ( ) ],
			\@tds);
		}

	print &ui_columns_end();
	print &ui_links_row(\@links);
	print &ui_form_end([ [ "delete", $text{'index_delete'} ] ]);
	}
else {
	# Tell the user there are none
	@pmrc = &procmail::get_procmailrc();
	if (@pmrc) {
		print "<b>$text{'index_none2'}</b><p>\n";
		}
	elsif (&get_global_spamassassin()) {
		print "<b>$text{'index_none3'}</b><p>\n";
		}
	else {
		print "<b>$text{'index_none'}</b><p>\n";
		}
	shift(@links);
	shift(@links);
	print &ui_links_row(\@links);
	}

&ui_print_footer("/", $text{'index'});

